# if we want to build against the included version of klibc or not.
# 0 - do not use klibc
# 1 - use klibc
# Watch out for where the linux symlink is in the klibc part of the tarball,
# it probably is not where you want it to be.
%define klibc 0

# if we want to have logging support in or not.
# 0 - no logging  support
# 1 - logging support
# Note, it is not recommend if you use klibc to enable logging.
%define log 1

# if we want to enable debugging support in udev.  If it is enabled, lots of 
# stuff will get sent to the debug syslog.
# 0 - debugging disabled
# 1 - debugging enabled
%define debug 0

# if we want to build the DBUS "extra" package or not
# 0 - no DBUS support
# 1 - DBUS support
%define dbus 1

# if we want to build the SELinux "extra" package or not
# 0 - no SELinux support
# 1 - SELinux support
%define selinux 1

# if we want to build the scsi_id "extra" package or not
# 0 - do not build the package
# 1 - build it
%define scsi_id 1

# if we want to build pam_console support
# 0 - do not build the package
# 1 - build it
%define pam_console 1


Summary: A userspace implementation of devfs
Name: udev
Version: 024
Release: 6
License: GPL
Group: Utilities/System
Source: ftp://ftp.kernel.org/pub/linux/utils/kernel/hotplug/%{name}-%{version}.tar.gz
Source1: udev.rules
Source2: udev.permissions
Source3: udev.conf
Source4: pam_console.dev
Source5: selinux.dev
Source6: udev.sysconfig
Source7: udev.hotplug
Source8: dbus.dev
%if %{pam_console}
Source10: pam_console_setowner-1.0.tgz
%endif
Patch1: udev-024-selinux.patch
Patch2: udev-024-dbus.patch
ExclusiveOS: Linux
URL: http://kernel.org/pub/linux/utils/kernel/hotplug/
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
Prereq: /bin/sh, fileutils, hotplug
%if %{selinux}
BuildRequires: libselinux-devel > 1.4-10
Requires: libselinux > 1.4-10
%endif
%if %{dbus}
BuildRequires: dbus-devel
Requires: dbus
%endif
%if %{pam_console}
BuildRequires: pam-devel
Requires: pam
%endif

%description
udev is a implementation of devfs in userspace using sysfs and
/sbin/hotplug. It requires a 2.6 kernel to run properly.

%prep
%if %{pam_console}
%setup -q -a 10
%else
%setup -q
%endif
%patch1 -p1 -b .sel
%patch2 -p1 -b .dbus

%build
%if %{klibc}
make CC="gcc $RPM_OPT_FLAGS -D_LINUX_CONFIG_H -include linux/autoconf.h" \
	USE_KLIBC=true		\
%else
make CC="gcc $RPM_OPT_FLAGS"    \
%endif
%if %{log}
	USE_LOG=true		\
%else
	USE_LOG=false		\
%endif
%if %{debug}
	DEBUG=true		\
%else
	DEBUG=false		\
%endif
	EXTRAS="	\
%if %{scsi_id}
	extras/scsi_id	\
%endif
%if %{dbus}
	extras/dbus	\
%endif
%if %{selinux} 
	extras/selinux	\
%endif
"

%if %{pam_console}
pushd pam_console_setowner
make
popd
%endif

%install
rm -rf $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT%{_sbindir}

make DESTDIR=$RPM_BUILD_ROOT install \
	EXTRAS="	\
%if %{scsi_id}
	extras/scsi_id	\
%endif
%if %{dbus}
	extras/dbus	\
%endif
%if %{selinux}
	extras/selinux	\
%endif
"


rm -f $RPM_BUILD_ROOT%{_sysconfdir}/udev/udev.rules
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/udev/udev.permissions
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/init.d/udev

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/udev/rules.d
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/udev/permissions.d
install -m 0644 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/udev/rules.d/50-udev.rules
install -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/udev/permissions.d/50-udev.permissions
install -m 0644 %{SOURCE3} $RPM_BUILD_ROOT%{_sysconfdir}/udev/udev.conf
install -m 0755 %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/dev.d/default
install -m 0755 %{SOURCE5} $RPM_BUILD_ROOT%{_sysconfdir}/dev.d/default
install -m 0755 %{SOURCE8} $RPM_BUILD_ROOT%{_sysconfdir}/dev.d/default

%if %{pam_console}
install -m 0755 pam_console_setowner/pam_console_setowner $RPM_BUILD_ROOT/sbin
%endif

mkdir $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig
install -m 0644 %{SOURCE6} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/udev

rm -f $RPM_BUILD_ROOT%{_sysconfdir}/hotplug.d/default/udev.hotplug
install -m 0644 %{SOURCE6} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/udev
install -m 0755 %{SOURCE7} $RPM_BUILD_ROOT%{_sysconfdir}/hotplug.d/default/udev.hotplug

#%post
#/sbin/chkconfig --add udev

%preun
if [ $1 = 0 -a -f %{_sysconfdir}/rc.d/init.d/udev ]; then
	/sbin/chkconfig --del udev
fi

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc COPYING README TODO ChangeLog HOWTO*  docs/*
%doc etc/udev/udev.rules.{examples,redhat}
%doc etc/udev/udev.permissions.redhat
%attr(0755,root,root) %dir /udev
%attr(0755,root,root) /sbin/udev
%attr(0755,root,root) %{_bindir}/udevinfo
%attr(0755,root,root) /sbin/udevsend
%attr(0755,root,root) /sbin/udevd
%attr(0755,root,root) %{_bindir}/udevtest
%attr(0755,root,root) /sbin/udevstart
%attr(0755,root,root) /sbin/udev_selinux
%if %{pam_console}
%attr(0755,root,root) /sbin/pam_console_setowner
%endif
%attr(0755,root,root) %dir %{_sysconfdir}/dev.d/
%attr(0755,root,root) %dir %{_sysconfdir}/dev.d/default
%config %attr(0755,root,root) %{_sysconfdir}/dev.d/net/hotplug.dev
%config %attr(0755,root,root) %{_sysconfdir}/dev.d/default/pam_console.dev
%config %attr(0755,root,root) %{_sysconfdir}/dev.d/default/selinux.dev
%config %attr(0755,root,root) %{_sysconfdir}/dev.d/default/dbus.dev
%attr(0755,root,root) %dir %{_sysconfdir}/udev/
%attr(0755,root,root) %dir %{_sysconfdir}/udev/rules.d/
%attr(0755,root,root) %dir %{_sysconfdir}/udev/permissions.d/
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/udev/udev.conf
%config %attr(0644,root,root) %{_sysconfdir}/udev/rules.d/50-udev.rules
%config %attr(0644,root,root) %{_sysconfdir}/udev/permissions.d/50-udev.permissions
%attr(0755,root,root) %{_sysconfdir}/hotplug.d/default/udev.hotplug
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/sysconfig/udev
%attr(0644,root,root) %{_mandir}/man8/udev*.8*

%if %{dbus}
	%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/dbus-1/system.d/udev_sysbus_policy.conf
	%attr(0755,root,root) /usr/sbin/udev_dbus
%endif

%if %{scsi_id}
	%attr(755,root,root) /sbin/scsi_id
	%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/scsi_id.config
	%attr(0644,root,root) %{_mandir}/man8/scsi_id*.8*
%endif

%changelog
* Mon May 10 2004 Elliot Lee <sopwith@redhat.com> 024-6
- Turn off udevd by default for FC2

* Tue Apr 20 2004 Harald Hoyer <harald@redhat.com> - 024-5
- fixed permission for /dev/tty (FC2)

* Thu Apr 15 2004 Harald Hoyer <harald@redhat.com> - 024-4
- moved the 00- files to 50-, to let the use place his files in front

* Thu Apr 15 2004 Harald Hoyer <harald@redhat.com> - 024-3
- set UDEV_SELINUX to yes
- added UDEV_LOG

* Thu Apr 15 2004 Harald Hoyer <harald@redhat.com> - 024-2
- added /udev to filelist

* Wed Apr 14 2004 Harald Hoyer <harald@redhat.com> - 024-1
- update to 024
- added /etc/sysconfig/udev
- added selinux, pam_console, dbus support

* Fri Mar 26 2004 Harald Hoyer <harald@redhat.com> - 023-1
- update to 023

* Wed Mar 24 2004 Bill Nottingham <notting@redhat.com> 022-1
- update to 022

* Sun Mar 21 2004 Florian La Roche <Florian.LaRoche@redhat.de>
- really move initscript

* Sun Feb 29 2004 Florian La Roche <Florian.LaRoche@redhat.de>
- move chkconv to preun
- nicer url

* Wed Feb 25 2004 Harald Hoyer <harald@redhat.com> - 018-1
- changes permissions and rules

* Mon Feb 23 2004 Dan Walsh <dwalsh@redhat.com>
- Add selinux support

* Thu Feb 19 2004 Greg Kroah-Hartman <greg@kroah.com>
- add some more files to the documentation directory
- add ability to build scsi_id and make it the default

* Mon Feb 16 2004 Greg Kroah-Hartman <greg@kroah.com>
- fix up udevd build, as it's no longer needed to be build seperatly
- add udevtest to list of files
- more Red Hat sync ups.

* Thu Feb 12 2004 Greg Kroah-Hartman <greg@kroah.com>
- add some changes from the latest Fedora udev release.

* Mon Feb 2 2004 Greg Kroah-Hartman <greg@kroah.com>
- add udevsend, and udevd to the files
- add ability to build udevd with glibc after the rest is build with klibc

* Mon Jan 26 2004 Greg Kroah-Hartman <greg@kroah.com>
- added udevinfo to rpm
- added URL to spec file
- added udevinfo's man page

* Mon Jan 05 2004 Rolf Eike Beer <eike-hotplug@sf-tec.de>
- add defines to choose the init script (Redhat or LSB)

* Tue Dec 16 2003 Robert Love <rml@ximian.com>
- install the initscript and run chkconfig on it

* Tue Nov 2 2003 Greg Kroah-Hartman <greg@kroah.com>
- changes due to config file name changes

* Fri Oct 17 2003 Robert Love <rml@tech9.net>
- Make work without a build root
- Correctly install the right files
- Pass the RPM_OPT_FLAGS to gcc so we can build per the build policy
- Put some prereqs in
- Install the hotplug symlink to udev

* Mon Jul 28 2003 Paul Mundt <lethal@linux-sh.org>
- Initial spec file for udev-0.2.
